"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
const dotenv_1 = __importDefault(require("dotenv"));
const index_route_1 = require("./routes/index.route");
const path_1 = __importDefault(require("path"));
const error_middleware_1 = require("./middlewares/error.middleware");
const db_config_1 = require("./configs/db.config");
const env = process.env.NODE_ENV || "development";
const envFile = `.env.${env}`;
dotenv_1.default.config({ path: path_1.default.resolve(envFile) });
const PORT = parseInt(process.env.API_PORT ?? "3001");
(async () => {
    await db_config_1.dbSequelize.authenticate();
    console.debug("Database Connection has been established successfully.");
})();
const app = (0, express_1.default)();
app.use("/", index_route_1.indexRouter);
app.listen(PORT, () => {
    console.log(`Server is running on http://localhost:${PORT}`);
    console.log(`Demo on http://localhost:${PORT}/info`);
});
app.use(error_middleware_1.errorHandlingMiddleware);
console.log("Hello, Node + TypeScript!");
