"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorHandlingMiddleware = void 0;
const base_error_1 = require("../dtos/error/base.error");
const common_constant_1 = require("../constants/common.constant");
const language_helper_1 = require("../helpers/language.helper");
const errorHandlingMiddleware = async (err, req, res, _next) => {
    let statusCode;
    let message;
    let errorResponse;
    // Using switch-case to handle different types of errors
    switch (true) {
        case err instanceof base_error_1.BusinessRuleException:
            statusCode = common_constant_1.HttpStatusCode.UNPROCESSABLE_ENTITY; // 422
            message = err.message || (0, language_helper_1.translateMessage)("BUSINESS_RULE_VIOLATION");
            break;
        case err instanceof base_error_1.UnauthorizedException:
            statusCode = common_constant_1.HttpStatusCode.UNAUTHORIZED; // 401
            message = err.message || (0, language_helper_1.translateMessage)("UNAUTHORIZED");
            break;
        case err instanceof base_error_1.NotFoundException:
            statusCode = common_constant_1.HttpStatusCode.NOT_FOUND; // 404
            message = err.message || (0, language_helper_1.getResponseMessage)("NOT_FOUND", "Resource");
            break;
        case err instanceof base_error_1.BadRequestException:
            statusCode = common_constant_1.HttpStatusCode.BAD_REQUEST; // 400
            message = err.message || (0, language_helper_1.translateMessage)("BAD_REQUEST");
            break;
        case err instanceof base_error_1.ForbiddenException:
            statusCode = common_constant_1.HttpStatusCode.FORBIDDEN; // 403
            message = err.message || (0, language_helper_1.translateMessage)(err.message);
            break;
        case err.name === "SequelizeConnectionRefusedError":
            statusCode = common_constant_1.HttpStatusCode.INTERNAL_SERVER_ERROR; // 500
            message = (0, language_helper_1.translateMessage)("DB_CONNECTION_FAILED");
            break;
        default: {
            statusCode = common_constant_1.HttpStatusCode.INTERNAL_SERVER_ERROR; // 500
            message = (0, language_helper_1.translateMessage)("UNHANDLED_ERROR");
            break;
        }
    }
    // Send a custom error response to the user
    errorResponse = {
        success: false,
        message: message,
    };
    res.status(statusCode).send(errorResponse);
};
exports.errorHandlingMiddleware = errorHandlingMiddleware;
