"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseLogic = void 0;
const base_error_1 = require("../dtos/error/base.error");
const language_helper_1 = require("../helpers/language.helper");
class BaseLogic {
    constructor(baseRepo, modelName) {
        this.baseRepo = baseRepo;
        this.modelName = modelName;
        this.findOne = async (filter = {}) => {
            const entity = await this.baseRepo.findOne(filter);
            if (!entity)
                throw new base_error_1.NotFoundException((0, language_helper_1.getResponseMessage)("NOT_FOUND", this.modelName));
            return entity;
        };
        this.findAll = async (filter = {}) => {
            const entities = await this.baseRepo.findAll(filter);
            return entities;
        };
        this.create = async (data, includeModels = [], transaction) => {
            return await this.baseRepo.create(data, includeModels, transaction);
        };
        this.bulkCreate = async (data, includeModels = []) => await this.baseRepo.bulkCreate(data, includeModels);
        this.update = async (id, data) => await this.baseRepo.update(id, data);
        this.delete = async (ids) => await this.baseRepo.delete(ids);
        this.paginate = async (page = 1, limit = 10, filter = {}) => await this.baseRepo.paginate(page, limit, filter);
    }
}
exports.BaseLogic = BaseLogic;
